@@ -421,34 +421,37 @@ create_combo_widget (const char *label_text, GtkWidget **widget,
 }
 #endif
 
-#define APPEND_ENTRY(data, i)                                                  \
-{                                                                              \
-    GtkWidget *label;                                                          \
-    (data)->widget = gtk_entry_new ();                                         \
-    if ((data)->label) {                                                       \
-        label = gtk_label_new (NULL);                                          \
-        gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _((data)->label));\
-        gtk_widget_show (label);                                               \
-        gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);                   \
-        gtk_misc_set_padding (GTK_MISC (label), 4, 0);                         \
-        gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,              \
-                          (GtkAttachOptions) (GTK_FILL),                       \
-                          (GtkAttachOptions) (GTK_FILL), 4, 4);                \
-        gtk_label_set_mnemonic_widget (GTK_LABEL (label), (data)->widget);     \
-    }                                                                          \
-    g_signal_connect ((gpointer) (data)->widget, "changed",                    \
-                      G_CALLBACK (on_default_editable_changed),                \
-                      (data));                                                 \
-    gtk_widget_show ((data)->widget);                                          \
-    gtk_table_attach (GTK_TABLE (table), (data)->widget, 1, 2, i, i+1,         \
-                      (GtkAttachOptions) (GTK_FILL|GTK_EXPAND),                \
-                      (GtkAttachOptions) (GTK_FILL), 4, 4);                    \
-                                                                               \
-    if (!__widget_tooltips)                                                    \
-        __widget_tooltips = gtk_tooltips_new();                                \
-    if ((data)->tooltip)                                                       \
-        gtk_tooltips_set_tip (__widget_tooltips, (data)->widget,               \
-                              _((data)->tooltip), NULL);                       \
+static void
+create_entry (StringConfigData *data, GtkTable *table, int i)
+{
+    (data)->widget = gtk_entry_new ();
+    GtkWidget *label = NULL;
+    if (_(data->label) && *_(data->label)) {
+        label = gtk_label_new (NULL);
+        gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _(data->label));
+        gtk_widget_show (label);
+        gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+        gtk_misc_set_padding (GTK_MISC (label), 4, 0);
+        gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (GTK_FILL), 4, 4);
+        gtk_label_set_mnemonic_widget (GTK_LABEL (label),
+                                       GTK_WIDGET (data->widget));
+    }
+    g_signal_connect ((gpointer) (data)->widget, "changed",
+                      G_CALLBACK (on_default_editable_changed),
+                      data);
+    gtk_widget_show (GTK_WIDGET (data->widget));
+    gtk_table_attach (GTK_TABLE (table), GTK_WIDGET (data->widget),
+                      1, 2, i, i+1,
+                      (GtkAttachOptions) (GTK_FILL|GTK_EXPAND),
+                      (GtkAttachOptions) (GTK_FILL), 4, 4);
+
+    if (!__widget_tooltips)
+        __widget_tooltips = gtk_tooltips_new();
+    if (data->tooltip)
+        gtk_tooltips_set_tip (__widget_tooltips, GTK_WIDGET (data->widget),
+                              _(data->tooltip), NULL);
 }
 
 static void
@@ -560,7 +563,7 @@ create_options_page ()
     gtk_container_add (GTK_CONTAINER (frame), table);
     gtk_widget_show (table);
     entry = find_string_config_entry (SCIM_CANNA_CONFIG_INIT_FILE_NAME);
-    APPEND_ENTRY(entry, 0);
+    create_entry (entry, GTK_TABLE (table), 0);
 
     g_signal_connect (G_OBJECT (widget), "toggled",
                       G_CALLBACK (on_toggle_button_toggled_set_sensitive),
@@ -580,7 +583,7 @@ create_options_page ()
     gtk_container_add (GTK_CONTAINER (frame), table);
     gtk_widget_show (table);
     entry = find_string_config_entry (SCIM_CANNA_CONFIG_SERVER_NAME);
-    APPEND_ENTRY(entry, 0);
+    create_entry (entry, GTK_TABLE (table), 0);
 
     g_signal_connect (G_OBJECT (widget), "toggled",
                       G_CALLBACK (on_toggle_button_toggled_set_sensitive),
